@@ -8,7 +8,7 @@
 
 #include <KCModuleInfo>
 #include <KIO/ApplicationLauncherJob>
-#include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
 
 ExternalAppModule::ExternalAppModule(QWidget *parent, const KService::Ptr &module)
     : module(module)
@@ -19,7 +19,7 @@ ExternalAppModule::ExternalAppModule(QWidget *parent, const KService::Ptr &modul
     externalModule.setupUi(this);
     QString moduleName = module->name();
     if (moduleName.isEmpty()) {
-        moduleName = module->property(QStringLiteral("X-KDE-PluginInfo-Name"), QVariant::String).toString();
+        moduleName = module->property(QStringLiteral("X-KDE-PluginInfo-Name"), QMetaType::QString).toString();
         if (!moduleName.isEmpty()) {
             qWarning() << "Reading deprecated X-KDE-PluginInfo-Name property from ExternalAppModule, use Name property instead";
         }
@@ -45,6 +45,6 @@ void ExternalAppModule::showEvent(QShowEvent *event)
 void ExternalAppModule::runExternal()
 {
     KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(module);
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
     job->start();
 }
